<?php

/**
 * Plugin Name: Gift Wrapper for WooCommerce
 * Description: Your users can gift wrap individual products from the product page or gift wrap their entire order. A fee can be charged for gift wrapping.
 * Version: 5.4.0
 * Author: Flintop
 * Author URI: https://woo.com/vendor/flintop/
 * Text Domain: gift-wrapper-for-woocommerce
 * Domain Path: /languages
 * Woo: 5544168:87cb4050d86f3664c88ec2fd17783c9f
 * Tested up to: 6.4.2
 * WC tested up to: 8.4.0
 * WC requires at least: 3.0.0
 * Copyright: © 2020 Flintop
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 */
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

/* Include once will help to avoid fatal error by load the files when you call init hook */
include_once ABSPATH . 'wp-admin/includes/plugin.php' ;

// Include main class file
if (!class_exists('FP_Gift_Wrapper')) {
	include_once 'inc/class-gift-wrapper.php';
}

if (!function_exists('gtw_is_plugin_active')) {

	/**
	 * Is plugin active?
	 * 
	 * @return bool
	 */
	function gtw_is_plugin_active() {
		if (gtw_is_valid_wordpress_version() && gtw_is_woocommerce_active() && gtw_is_valid_woocommerce_version()) {
			return true;
		}

		add_action('admin_notices', 'gtw_display_warning_message');

		return false;
	}

}

if (!function_exists('gtw_is_woocommerce_active')) {

	/**
	 * Function to check whether WooCommerce is active or not.
	 * 
	 * @return bool
	 */
	function gtw_is_woocommerce_active() {
		$return = true;
		// This condition is for multi site installation.
		if (is_multisite() && !is_plugin_active_for_network('woocommerce/woocommerce.php') && !is_plugin_active('woocommerce/woocommerce.php')) {
			$return = false;
			// This condition is for single site installation.
		} elseif (!is_plugin_active('woocommerce/woocommerce.php')) {
			$return = false;
		}

		return $return;
	}

}

if (!function_exists('gtw_is_valid_wordpress_version')) {

	/**
	 * Is valid WordPress version?
	 * 
	 * @return bool
	 */
	function gtw_is_valid_wordpress_version() {
		if (version_compare(get_bloginfo('version'), FP_Gift_Wrapper::$wp_minimum_version, '<')) {
			return false;
		}

		return true;
	}

}

if (!function_exists('gtw_is_valid_woocommerce_version')) {

	/**
	 * Is valid WooCommerce version?
	 * 
	 * @return bool
	 */
	function gtw_is_valid_woocommerce_version() {
		if (version_compare(get_option('woocommerce_version'), FP_Gift_Wrapper::$wc_minimum_version, '<')) {
			return false;
		}

		return true;
	}

}

if (!function_exists('gtw_display_warning_message')) {

	/**
	 * Display the WooCommere is not active warning message.
	 */
	function gtw_display_warning_message() {
		$notice = '';

		if (!gtw_is_valid_wordpress_version()) {
			$notice = sprintf('This version of Gift Wrapper for WooCommerce requires WordPress %1s or newer.', FP_Gift_Wrapper::$wp_minimum_version);
		} elseif (!gtw_is_woocommerce_active()) {
			$notice = 'Gift Wrapper for WooCommerce Plugin will not work until WooCommerce Plugin is Activated. Please Activate the WooCommerce Plugin.';
		} elseif (!gtw_is_valid_woocommerce_version()) {
			$notice = sprintf('This version of Gift Wrapper for WooCommerce requires WooCommerce %1s or newer.', FP_Gift_Wrapper::$wc_minimum_version);
		}

		if ($notice) {
			echo '<div class="error">';
			echo '<p>' . wp_kses_post($notice) . '</p>';
			echo '</div>';
		}
	}

}

// Return if the plugin is not active.
if (!gtw_is_plugin_active()) {
	return;
}

// Define constant
if (!defined('GTW_PLUGIN_FILE')) {
	define('GTW_PLUGIN_FILE', __FILE__);
}

// return Gift Wrapper class object
if (!function_exists('GTW')) {

	function GTW() {
		return FP_Gift_Wrapper::instance();
	}

}

// initialize the plugin.
GTW();
