<?php

/**
 * WooCommerce Product Bundles Compatibility.
 */
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

if (!class_exists('GTW_Product_Bundles_Compatibility')) {

	/**
	 * Class.
	 */
	class GTW_Product_Bundles_Compatibility extends GTW_Compatibility {

		/**
		 * Cart item key position.
		 * 
		 * @since 5.4.0
		 * @var int/boolean
		 */
		private static $cart_item_key_position = false;

		/**
		 * Class Constructor.
		 */
		public function __construct() {
			$this->id = 'product_bundles';

			parent::__construct();
		}

		/**
		 * Is plugin enabled?.
		 *
		 * @since 1.0.0
		 * @return bool
		 * */
		public function is_plugin_enabled() {
			return class_exists('WC_Bundles');
		}

		/**
		 * Action
		 */
		public function actions() {
			// Stamp products not allowed to gift wrapper while add to cart it.
			add_filter('gtw_validate_gift_wrapper_cart_item_data', array( $this, 'validate_stamp_products_gift_wrap' ), 10, 3);
			// Stop stamp products allowed to gift wrapper in the cart page
			add_filter('gtw_is_valid_edit_product_gift_wrapper', array( $this, 'validate_edit_products_gift_wrap' ), 10, 3);
			// May be add custom bundled cart item data.
			add_filter('woocommerce_bundled_item_cart_data', array( $this, 'maybe_add_custom_bundled_cart_item_data' ), 10, 2);
		}

		/**
		 * Validate the stamp product to gift wrap while add to cart it.
		 * 
		 * @since 1.0.0
		 * @param bool $bool
		 * @param array $cart_item_data
		 * @param int $product_id
		 * @return bool
		 */
		public function validate_stamp_products_gift_wrap( $bool, $cart_item_data, $product_id ) {
			// Return true, if the products is a bundled product.
			if (wc_pb_maybe_is_bundled_cart_item($cart_item_data)) {
				return true;
			}

			return $bool;
		}

		/**
		 * Stop stamp products allowed to gift wrapper in the cart page.
		 * 
		 * @since 5.4.0
		 * @param bool $bool
		 * @param array $cart_item_data
		 * @param int $product_id
		 * @return bool
		 */
		public function validate_edit_products_gift_wrap( $bool, $cart_item_data, $product_id ) {
			// Return true, if the products is a bundled product.
			if (wc_pb_maybe_is_bundled_cart_item($cart_item_data)) {
				return false;
			}

			return $bool;
		}

		/**
		 * May be add custom bundled cart item data.
		 * 
		 * @since 5.4.0
		 * @param array $bundled_cart_item_data
		 * @param array $cart_item_data
		 * @return array
		 */
		public function maybe_add_custom_bundled_cart_item_data( $bundled_cart_item_data, $cart_item_data ) {
			if (!isset($cart_item_data['gtw_cart_item_position'])) {
				return $bundled_cart_item_data;
			}

			self::$cart_item_key_position = self::$cart_item_key_position ? self::$cart_item_key_position + 1 : $cart_item_data['gtw_cart_item_position'] + 1;

			$bundled_cart_item_data['gtw_cart_item_position'] = self::$cart_item_key_position;

			return $bundled_cart_item_data;
		}
	}

}
