<?php

/**
 * WPML Compatibility.
 */
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

if (!class_exists('GTW_WPML_Compatibility')) {

	/**
	 * Class GTW_WPML_Compatibility.
	 */
	class GTW_WPML_Compatibility extends GTW_Compatibility {

		/**
		 * Context
		 *
		 * @var string
		 */
		private $context = 'gift-wrapper-for-woocommerce';

		/**
		 * Class Constructor.
		 */
		public function __construct() {
			$this->id = 'wpml';

			parent::__construct();
		}

		/**
		 * Is plugin enabled?.
		 *
		 *  @return bool
		 * */
		public function is_plugin_enabled() {

			return function_exists('icl_register_string');
		}

		/**
		 * Admin Action.
		 */
		public function admin_action() {

			// Register the string.
			add_filter('admin_init', array( $this, 'register_string' ), 10, 3);
		}

		/**
		 * Action
		 */
		public function actions() {

			// Alter the WC categories.
			add_filter('gtw_wc_categories', array( $this, 'alter_wc_categories_params' ), 10, 1);
			// Get the string.
			add_filter('gtw_custom_field_translate_string', array( $this, 'translate_string' ), 10, 3);
		}

		/**
		 * Alter the WC categories.
		 * 
		 * @since 4.7
		 * @return array
		 */
		public function alter_wc_categories_params( $categories ) {
			global $sitepress;
			$taxonomy = 'product_cat';
			if ($sitepress) {
				remove_filter('get_terms_args', array( $sitepress, 'get_terms_args_filter' ));
				remove_filter('get_term', array( $sitepress, 'get_term_adjust_id' ));
				remove_filter('terms_clauses', array( $sitepress, 'terms_clauses' ));
				$categories = get_terms(array( 'taxonomy' => $taxonomy, 'hide_empty' => false )); // Change the args accordingly
				add_filter('terms_clauses', array( $sitepress, 'terms_clauses' ), 10, 4);
				add_filter('get_term', array( $sitepress, 'get_term_adjust_id' ), 1, 1);
				add_filter('get_terms_args', array( $sitepress, 'get_terms_args_filter' ), 10, 2);
			} else {
				$categories = get_terms(array( 'taxonomy' => $taxonomy, 'hide_empty' => false )); // Change the args accordingly
			}

			return $categories;
		}

		/**
		 * Register the string in WPML.
		 */
		public function register_string() {

			$custom_field_ids = gtw_get_custom_field_ids();
			// Return if the custom field ids not exists.
			if (!gtw_check_is_array($custom_field_ids)) {
				return;
			}

			foreach ($custom_field_ids as $custom_field_id) {
				$custom_field = gtw_get_custom_field($custom_field_id);

				$register_strings = array(
					'gtw_custom_field_name_' . $custom_field_id => $custom_field->get_name(),
					'gtw_custom_field_description_' . $custom_field_id => $custom_field->get_description(),
				);

				foreach ($register_strings as $name => $value) {
					// Registering the custom field string.
					icl_register_string($this->context, $name, $value);
				}
			}
		}

		/**
		 * Get the string in WPML.
		 *
		 * @return string
		 */
		public function translate_string( $value, $option_name, $language ) {
			$has_translation = null;

			return icl_translate($this->context, $option_name, $value, false, $has_translation, $language);
		}
	}

}
