<?php

/**
 * Short codes.
 * */
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}
if (!class_exists('GTW_Shortcodes')) {

	/**
	 * Class.
	 */
	class GTW_Shortcodes {

		/**
		 * Class Initialization.
		 * */
		public static function init() {
			/**
			 * This hook is used to load extra shortcodes.
			 * 
			 * @since 1.0
			 */
			$shortcodes = apply_filters('gtw_load_shortcodes', array(
				'gtw_product_gift_wrapper',
				'gtw_order_gift_wrapper',
				'gtw_order_gift_wrapper_remove_notice',
				'gtw_order_gift_wrapper_non_applicable_products_notice',
			));

			foreach ($shortcodes as $shortcode_name) {
				// Add a shortcode.
				add_shortcode($shortcode_name, array( __CLASS__, 'process_shortcode' ));
			}
		}

		/**
		 * Process the shortcode.
		 *
		 * @return mixed
		 * */
		public static function process_shortcode( $atts, $content, $tag ) {
			$shortcode_name = str_replace('gtw_', '', $tag);
			$function = 'shortcode_' . $shortcode_name;

			switch ($shortcode_name) {
				case 'product_gift_wrapper':
				case 'order_gift_wrapper':
				case 'order_gift_wrapper_remove_notice':
				case 'order_gift_wrapper_non_applicable_products_notice':
					ob_start();
					self::$function($atts, $content); // output for shortcode.
					$content = ob_get_contents();
					ob_end_clean();
					break;

				default:
					ob_start();
					/**
					 * This hook is used to display the shortcode content.
					 * 
					 * @since 1.0
					 */
					do_action("gtw_shortcode_{$shortcode_name}_content");
					$content = ob_get_contents();
					ob_end_clean();
					break;
			}

			return $content;
		}

		/**
		 * Display the content of the product gift wrapper.
		 * 
		 * @since 4.8
		 * */
		public static function shortcode_product_gift_wrapper( $atts, $content ) {
			global $product;

			$atts = shortcode_atts(array(
				'product_id' => '',
					), $atts, 'gtw_product_gift_wrapper');

			$product = $atts['product_id'] ? wc_get_product($atts['product_id']) : $product;
			if (!is_object($product)) {
				return;
			}

			$product_id = $product->is_type('variation') ? $product->get_parent_id() : $atts['product_id'];
			$variation_id = $product->is_type('variation') ? $product->get_id() : false;

			GTW_Frontend::render_gift_wrapper($product, $product_id, $variation_id);
		}

		/**
		 * Display the content of the order gift wrapper.
		 *
		 * @return void
		 * */
		public static function shortcode_order_gift_wrapper( $atts, $content ) {

			GTW_Frontend::render_order_gift_wrapper('shortcode');
		}

		/**
		 * Display the content of the order gift wrapper remove notice.
		 *
		 * @return void
		 * */
		public static function shortcode_order_gift_wrapper_remove_notice( $atts, $content ) {

			GTW_Frontend::add_remove_order_gift_wrapper_notice();
		}

		/**
		 * Display the content of the order gift wrapper exclude products notice.
		 *
		 * @return void
		 * */
		public static function shortcode_order_gift_wrapper_non_applicable_products_notice( $atts, $content ) {

			GTW_Frontend::order_gift_wrapper_exclude_products_notice();
		}
	}

	GTW_Shortcodes::init();
}
