<?php

/**
 * Common functions.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit ; // Exit if accessed directly.
}

include_once 'gtw-layout-functions.php' ;
include_once 'gtw-post-functions.php' ;
include_once 'gtw-template-functions.php' ;

if ( ! function_exists( 'gtw_check_is_array' ) ) {

	/**
	 * Check if resource is array.
	 *
	 * @return bool
	 */
	function gtw_check_is_array( $data ) {
		return ( is_array( $data ) && ! empty( $data ) ) ;
	}

}

if ( ! function_exists( 'gtw_page_screen_ids' ) ) {

	/**
	 * Get page screen IDs.
	 *
	 * @return array
	 */
	function gtw_page_screen_ids() {
		$wc_screen_id = sanitize_title( __( 'WooCommerce' , 'woocommerce' ) ) ;

		/**
		 * This hook is used to alter the page screen IDs.
		 * 
		 * @since 1.0
		 */
		return apply_filters(
				'gtw_page_screen_ids' , array(
			'product',
			$wc_screen_id . '_page_gtw_settings',
				)
		) ;
	}

}

if ( ! function_exists( 'gtw_get_allowed_setting_tabs' ) ) {

	/**
	 * Get setting tabs.
	 *
	 * @return array
	 */
	function gtw_get_allowed_setting_tabs() {
		/**
		 * This hook is used to alter the settings tabs array.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_settings_tabs_array' , array() ) ;
	}

}

if ( ! function_exists( 'gtw_get_settings_page_url' ) ) {

	/**
	 * Get Settings page URL.
	 *
	 * @return URL
	 */
	function gtw_get_settings_page_url( $args = array() ) {

		$url = add_query_arg( array( 'page' => 'gtw_settings' ) , admin_url( 'admin.php' ) ) ;

		if ( gtw_check_is_array( $args ) ) {
			$url = add_query_arg( $args , $url ) ;
		}

		return $url ;
	}

}

if ( ! function_exists( 'gtw_get_field_page_url' ) ) {

	/**
	 * Get the field page URL.
	 *
	 * @return URL
	 */
	function gtw_get_field_page_url( $args = array() ) {

		$url = add_query_arg( array( 'page' => 'gtw_settings', 'tab' => 'custom_fields' ) , admin_url( 'admin.php' ) ) ;

		if ( gtw_check_is_array( $args ) ) {
			$url = add_query_arg( $args , $url ) ;
		}

		return $url ;
	}

}

if ( ! function_exists( 'gtw_get_wc_categories' ) ) {

	/**
	 * Get WC Categories.
	 *
	 * @return array
	 */
	function gtw_get_wc_categories() {
		static $categories ;
		if ( isset( $categories ) ) {
			return $categories ;
		}

		$categories    = array() ;
		/**
		 * This hook is used to alter the WooCommerce categories.
		 * 
		 * @since 4.7
		 */
		$wc_categories = apply_filters( 'gtw_wc_categories' , get_terms( 'product_cat' ) ) ;

		if ( ! gtw_check_is_array( $wc_categories ) ) {
			return $categories ;
		}

		foreach ( $wc_categories as $category ) {
			$categories[ $category->term_id ] = $category->name ;
		}

		return $categories ;
	}

}

if ( ! function_exists( 'gtw_get_wp_user_roles' ) ) {

	/**
	 * Get the WordPress User Roles.
	 *
	 * @since 4.7
	 * @return array
	 */
	function gtw_get_wp_user_roles() {
		global $wp_roles ;

		static $user_roles ;
		if ( isset( $user_roles ) ) {
			return $user_roles ;
		}

		$user_roles = array() ;
		if ( ! isset( $wp_roles->roles ) || ! gtw_check_is_array( $wp_roles->roles ) ) {
			return $user_roles ;
		}

		foreach ( $wp_roles->roles as $slug => $role ) {
			$user_roles[ $slug ] = $role[ 'name' ] ;
		}

		return $user_roles ;
	}

}

if ( ! function_exists( 'gtw_get_popup_gift_wrapper_per_page_count' ) ) {

	/**
	 * Get the popup gift wrapper per page count.
	 *
	 * @return string/integer
	 */
	function gtw_get_popup_gift_wrapper_per_page_count() {
		/**
		 * This hook is used to alter the popup gift wrapper per page count.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_popup_gift_wrapper_per_page_count' , get_option( 'gtw_settings_popup_designs_pagination' , 8 ) ) ;
	}

}

if ( ! function_exists( 'gtw_get_slide_gift_wrapper_per_page_count' ) ) {

	/**
	 * Get the slide gift wrapper per page count.
	 *
	 * @return string/integer
	 */
	function gtw_get_slide_gift_wrapper_per_page_count() {
		/**
		 * This hook is used to alter the slide gift wrapper per page count.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_slide_gift_wrapper_per_page_count' , get_option( 'gtw_settings_toggle_designs_pagination' , 4 ) ) ;
	}

}

if ( ! function_exists( 'gtw_get_price_to_display' ) ) {

	/**
	 * Returns the price including or excluding tax, based on the 'woocommerce_tax_display_shop' setting.
	 *
	 * @return bool/String
	 */
	function gtw_get_price_to_display( $product, $price, $qty = 1 ) {

		if ( empty( $price ) ) {
			return 0 ;
		}

		$args = array(
			'qty'   => 1,
			'price' => $price,
		) ;

		return wc_get_price_to_display( $product , $args ) ;
	}

}

if ( ! function_exists( 'gtw_get_total_payable_price' ) ) {

	/**
	 * Returns the total payable price.
	 *
	 * @return float
	 */
	function gtw_get_total_payable_price( $product, $price, $rule = false ) {

		$gift_price    = ( float ) gtw_get_price_to_display( $product , $price ) ;
		$product_price = ( float ) wc_get_price_to_display( $product ) ;

		return $gift_price + $product_price ;
	}

}

if ( ! function_exists( 'gtw_get_default_design_price' ) ) {

	/**
	 * Get the default price.
	 *
	 * @return float
	 */
	function gtw_get_default_design_price() {
		/**
		 * This hook is used to alter the default design price.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_default_design_price' , floatval( get_option( 'gtw_settings_gift_wrapper_design_price' ) ) ) ;
	}

}

if ( ! function_exists( 'gtw_convert_price' ) ) {

	/**
	 * Convert the price.
	 *
	 * @return float
	 */
	function gtw_convert_price( $price, $currency = false ) {
		/**
		 * This hook is used to convert design price.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_convert_price' , $price , $currency ) ;
	}

}

if ( ! function_exists( 'gtw_create_new_product' ) ) {

	/**
	 * Create new a product.
	 *
	 * @return Integer
	 * */
	function gtw_create_new_product( $product_title ) {
		$args = array(
			'post_author' => get_current_user_id(),
			'post_status' => 'publish',
			'post_title'  => $product_title,
			'post_type'   => 'product',
		) ;

		$product_id = wp_insert_post( $args ) ;

		$terms = array( 'exclude-from-search', 'exclude-from-catalog' ) ; // For hidden..
		wp_set_post_terms( $product_id , $terms , 'product_visibility' , false ) ;

		$meta_keys = array(
			'_stock_status'      => 'instock',
			'total_sales'        => '0',
			'_downloadable'      => 'no',
			'_virtual'           => 'yes',
			'_regular_price'     => '0',
			'_price'             => '0',
			'_sale_price'        => '',
			'_featured'          => '',
			'_sold_individually' => 'yes',
			'_manage_stock'      => 'no',
			'_backorders'        => 'no',
			'_stock'             => '',
		) ;

		foreach ( $meta_keys as $key => $value ) {
			update_post_meta( $product_id , sanitize_key( $key ) , $value ) ;
		}

		return $product_id ;
	}

}

if ( ! function_exists( 'gtw_get_order_gift_wrapper_product' ) ) {

	/**
	 * Get order gift wrapper product.
	 *
	 * @return string/integer
	 */
	function gtw_get_order_gift_wrapper_product() {

		$selected_product = get_option( 'gtw_settings_order_gift_wrapper_product' ) ;

		if ( ! gtw_check_is_array( $selected_product ) ) {
			return false ;
		}

		return reset( $selected_product ) ;
	}

}

if ( ! function_exists( 'gtw_get_custom_field_translate_string' ) ) {

	/**
	 * Get the custom field translated string.
	 *
	 * @return mixed
	 */
	function gtw_get_custom_field_translate_string( $option_name, $value, $language = null ) {
		/**
		 * This hook is used to alter the custom field translate string.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_custom_field_translate_string' , $value , $option_name , $language ) ;
	}

}

if ( ! function_exists( 'gtw_get_product_rule_image_url' ) ) {

	/**
	 * Get the product rule image URL.
	 *
	 * @return mixed
	 */
	function gtw_get_product_rule_image_url( $image_id ) {

		return empty( $image_id ) ? wc_placeholder_img_src() : wp_get_attachment_url( $image_id ) ;
	}

}

if ( ! function_exists( 'gtw_get_order_gift_wrapper_display_type' ) ) {

	/**
	 * Get the order gift wrapper display type.
	 *
	 * @return string
	 */
	function gtw_get_order_gift_wrapper_display_type() {
		$type = get_option( 'gtw_settings_order_gw_display_type' ) ;
		switch ( $type ) {
			case '2':
				$display_type = 'slide' ;
				break ;

			default:
				$display_type = 'popup' ;
				break ;
		}

		/**
		 * This hook is used to alter the order gift wrapper display type.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_order_gift_wrapper_display_type' , $display_type ) ;
	}

}

if ( ! function_exists( 'gtw_get_product_gift_wrapper_display_type' ) ) {

	/**
	 * Get the product gift wrapper display type.
	 *
	 * @return string
	 */
	function gtw_get_product_gift_wrapper_display_type() {
		$type = get_option( 'gtw_settings_product_gw_display_type' ) ;
		switch ( $type ) {
			case '2':
				$display_type = 'slide' ;
				break ;

			default:
				$display_type = 'popup' ;
				break ;
		}

		/**
		 * This hook is used to alter the product gift wrapper display type.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_product_gift_wrapper_display_type' , $display_type ) ;
	}

}

if ( ! function_exists( 'gtw_get_product_gift_wrapper_rules' ) ) {

	/**
	 * Get the product gift wrapper rules.
	 *
	 * @return string
	 */
	function gtw_get_product_gift_wrapper_rules( $product_id ) {
		$design_type   = get_post_meta( $product_id , '_gtw_design_type' , true ) ;
		$gift_wrappers = ( '2' == $design_type ) ? array_filter( ( array ) get_post_meta( $product_id , '_gtw_designs' , true ) ) : gtw_get_active_rule_ids() ;

		/**
		 * This hook is used to alter the product gift wrapper rules.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_product_gift_wrapper_rules' , $gift_wrappers , $product_id ) ;
	}

}

if ( ! function_exists( 'gtw_format_product_rule' ) ) {

	/**
	 * Format the product rule.
	 *
	 * @return array
	 */
	function gtw_format_product_rule( $rule ) {
		$default_args = array(
			'name'     => '',
			'id'       => '',
			'price'    => '',
			'image_id' => '',
		) ;

		if ( is_array( $rule ) ) {
			return wp_parse_args( $rule , $default_args ) ;
		}

		$gift_wrapper = gtw_get_rule( $rule ) ;
		if ( ! $gift_wrapper->exists() ) {
			return $default_args ;
		}

		$args = array(
			'name'     => $gift_wrapper->get_name(),
			'id'       => $gift_wrapper->get_id(),
			'price'    => $gift_wrapper->get_price(),
			'image_id' => $gift_wrapper->get_image_id(),
		) ;

		return $args ;
	}

}

if ( ! function_exists( 'gtw_get_product_rule_by_id' ) ) {

	/**
	 * Get the product rule by ID.
	 *
	 * @return array
	 */
	function gtw_get_product_rule_by_id( $product_id, $rule_id ) {
		$design_type = get_post_meta( $product_id , '_gtw_design_type' , true ) ;

		if ( '2' == $design_type ) {
			$rules   = array_filter( ( array ) get_post_meta( $product_id , '_gtw_designs' , true ) ) ;
			$rule_id = ( array_key_exists( $rule_id , $rules ) ) ? $rules[ $rule_id ] : array() ;
		}

		return gtw_format_product_rule( $rule_id ) ;
	}

}

if ( ! function_exists( 'gtw_get_order_gift_wrapper_field_type' ) ) {

	/**
	 * Get the order gift wrapper field type.
	 *
	 * @since 5.1.0
	 * @return string
	 */
	function gtw_get_order_gift_wrapper_field_type() {

		return get_option( 'gtw_settings_order_gift_wrapper_field_type' ) ;
	}

}

if ( ! function_exists( 'gtw_add_notice' ) ) {

	/**
	 * Add the gift wrapper notice.
	 *
	 * @since 5.3.0
	 * @param string $message 
	 * @param string $notice_type
	 * @param array $data
	 * @return string
	 */
	function gtw_add_notice( $message, $notice_type = 'success', $data = array() ) {
		//Don't add the notice has already been added.
		if ( wc_has_notice( $message , $notice_type ) ) {
			return ;
		}

		wc_add_notice( $message , $notice_type , $data ) ;
	}

}

if ( ! function_exists( 'gtw_allow_both_gift_wrappers' ) ) {

	/**
	 * Get allow both gift wrappers option.
	 *
	 * @since 5.3.0
	 * @return bool
	 */
	function gtw_allow_both_gift_wrappers() {
			return 'yes' === get_option('gtw_settings_allow_both_gift_wrappers');
	}

}

if ( ! function_exists( 'gtw_get_add_gift_wrapper_cart_item_label' ) ) {

	/**
	 * Get add gift wrapper cart item label.
	 *
	 * @since 5.3.0
	 * @return string
	 */
	function gtw_get_add_gift_wrapper_cart_item_label() {
			return get_option('gtw_settings_add_gift_wrapper_cart_item_label');
	}

}
