<?php

/**
 * Post functions.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit ; // Exit if accessed directly.
}

if ( ! function_exists( 'gtw_create_new_rule' ) ) {

	/**
	 * Create a new rule.
	 *
	 * @return integer/string
	 */
	function gtw_create_new_rule( $meta_args, $post_args = array() ) {

		$object = new GTW_RULE() ;
		$id     = $object->create( $meta_args, $post_args ) ;

		return $id ;
	}

}

if ( ! function_exists( 'gtw_get_rule' ) ) {

	/**
	 * Get the rule object.
	 *
	 * @return object
	 */
	function gtw_get_rule( $id ) {

		$object = new GTW_RULE( $id ) ;

		return $object ;
	}

}

if ( ! function_exists( 'gtw_update_rule' ) ) {

	/**
	 * Update the rule.
	 *
	 * @return object
	 */
	function gtw_update_rule( $id, $meta_args, $post_args = array() ) {

		$object = new GTW_RULE( $id ) ;
		$object->update( $meta_args, $post_args ) ;

		return $object ;
	}

}

if ( ! function_exists( 'gtw_delete_rule' ) ) {

	/**
	 * Delete the rule.
	 *
	 * @return bool
	 */
	function gtw_delete_rule( $id, $force = true ) {

		wp_delete_post( $id, $force ) ;

		return true ;
	}

}

if ( ! function_exists( 'gtw_get_rule_statuses' ) ) {

	/**
	 * Get the rule statuses.
	 *
	 * @return array
	 */
	function gtw_get_rule_statuses() {
		/**
		 * This hook is used to alter the rule post statuses.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_rule_statuses', array( 'gtw_active', 'gtw_inactive' ) ) ;
	}

}

if ( ! function_exists( 'gtw_create_new_custom_field' ) ) {

	/**
	 * Create a new custom field.
	 *
	 * @return integer/string
	 */
	function gtw_create_new_custom_field( $meta_args, $post_args = array() ) {

		$object = new GTW_Custom_Field() ;
		$id     = $object->create( $meta_args, $post_args ) ;

		return $id ;
	}

}

if ( ! function_exists( 'gtw_get_custom_field' ) ) {

	/**
	 * Get the custom field object.
	 *
	 * @return object
	 */
	function gtw_get_custom_field( $id ) {

		$object = new GTW_Custom_Field( $id ) ;

		return $object ;
	}

}

if ( ! function_exists( 'gtw_update_custom_field' ) ) {

	/**
	 * Update the custom field.
	 *
	 * @return object
	 */
	function gtw_update_custom_field( $id, $meta_args, $post_args = array() ) {

		$object = new GTW_Custom_Field( $id ) ;
		$object->update( $meta_args, $post_args ) ;

		return $object ;
	}

}

if ( ! function_exists( 'gtw_delete_custom_field' ) ) {

	/**
	 * Delete the custom field.
	 *
	 * @return bool
	 */
	function gtw_delete_custom_field( $id, $force = true ) {

		wp_delete_post( $id, $force ) ;

		return true ;
	}

}

if ( ! function_exists( 'gtw_get_custom_field_statuses' ) ) {

	/**
	 * Get the custom field statuses.
	 *
	 * @return array
	 */
	function gtw_get_custom_field_statuses() {
		/**
		 * This hook is used to alter the custom fields post statuses.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_custom_field_statuses', array( 'gtw_active', 'gtw_inactive' ) ) ;
	}

}

if ( ! function_exists( 'gtw_get_active_rule_ids' ) ) {

	/**
	 * Get active rule IDs.
	 *
	 * @return array
	 */
	function gtw_get_active_rule_ids() {

		return gtw_get_rule_ids( 'gtw_active' ) ;
	}

}

if ( ! function_exists( 'gtw_get_rule_ids' ) ) {

	/**
	 * Get the rule IDs.
	 *
	 * @return array
	 */
	function gtw_get_rule_ids( $post_status = 'all' ) {
		if ( 'all' == $post_status ) {
			$post_status = gtw_get_rule_statuses() ;
		}

		$args = array(
			'post_type'      => GTW_Register_Post_Types::RULE_POSTTYPE,
			'post_status'    => $post_status,
			'posts_per_page' => '-1',
			'fields'         => 'ids',
			'orderby'        => 'menu_order ID',
			'order'          => 'ASC',
				) ;

		return get_posts( $args ) ;
	}

}

if ( ! function_exists( 'gtw_get_active_custom_field_ids' ) ) {

	/**
	 * Get the active custom field ids.
	 *
	 * @return array
	 */
	function gtw_get_active_custom_field_ids() {

		return gtw_get_custom_field_ids( 'gtw_active' ) ;
	}

}

if ( ! function_exists( 'gtw_get_custom_field_ids' ) ) {

	/**
	 * Get the custom field ids.
	 *
	 * @return array
	 */
	function gtw_get_custom_field_ids( $post_status = 'all' ) {
		if ( 'all' == $post_status ) {
			$post_status = gtw_get_custom_field_statuses() ;
		}

		$args = array(
			'post_type'      => GTW_Register_Post_Types::CUSTOM_FIELD_POSTTYPE,
			'post_status'    => $post_status,
			'posts_per_page' => '-1',
			'fields'         => 'ids',
			'orderby'        => 'menu_order ID',
			'order'          => 'ASC',
				) ;

		return get_posts( $args ) ;
	}

}
