<?php

/**
 * Template functions.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit ; // Exit if accessed directly.
}

if ( ! function_exists( 'gtw_get_order_gift_wrapper_classes' ) ) {

	/**
	 *  Get the order gift wrapper classes.
	 *
	 *  @return array
	 */
	function gtw_get_order_gift_wrapper_classes( $extra_content_type ) {
		$classes = array(
			'button',
			'gtw-order-gift-wrapper',
				) ;

		switch ( $extra_content_type ) {
			case 'slide':
				$classes[] = 'gtw-slide-order-gift-wrapper' ;
				break ;
			case 'popup':
				$classes[] = 'gtw-popup-gift-wrapper' ;
				break ;
			default:
				$classes[] = 'gtw-add-order-gift-wrapper' ;
				break ;
		}

		/**
		 * This hook is used to alter the order gift wrapper classes.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_order_gift_wrapper_classes' , $classes ) ;
	}

}


if ( ! function_exists( 'gtw_get_order_gift_wrapper_checkbox_classes' ) ) {

	/**
	 *  Get the order gift wrapper checkbox classes.
	 *
	 *  @since 5.1.0
	 *  @return array
	 */
	function gtw_get_order_gift_wrapper_checkbox_classes( $extra_content_type ) {
		$classes = array(
						'checkbox',
			'gtw-order-gift-wrapper',
				) ;

		if ( gtw_order_gift_wrapper_in_cart() ) {
			$classes[] = 'gtw-uncheck-order-gift-wrapper' ;
		} else {
			switch ( $extra_content_type ) {
				case 'slide':
					$classes[] = 'gtw-slide-order-gift-wrapper' ;
					break ;
				case 'popup':
					$classes[] = 'gtw-popup-gift-wrapper' ;
					break ;
				default:
					$classes[] = 'gtw-add-order-gift-wrapper' ;
					break ;
			}
		}


		/**
		 * This hook is used to alter the order gift wrapper checkbox classes.
		 * 
		 * @since 5.1.0
		 */
		return apply_filters( 'gtw_order_gift_wrapper_checkbox_classes' , $classes ) ;
	}

}

if ( ! function_exists( 'gtw_get_popup_order_gift_wrapper_classes' ) ) {

	/**
	 *  Get the order gift wrapper popup classes.
	 *
	 *  @return array
	 */
	function gtw_get_popup_order_gift_wrapper_classes( $gift_wrapper_id, $current_item = false ) {
		$classes = array(
			'gtw-popup-order-gift-wrapper-item',
			'gtw-popup-order-gift-wrapper-list',
			'gtw-popup-order-gift-wrapper-item-' . $gift_wrapper_id,
				) ;

		if ( $gift_wrapper_id == $current_item ) {
			$classes[] = 'gtw_current' ;
		}

		return $classes ;
	}

}

if ( ! function_exists( 'gtw_get_slide_order_gift_wrapper_classes' ) ) {

	/**
	 *  Get the order gift wrapper slide classes.
	 *
	 *  @return array
	 */
	function gtw_get_slide_order_gift_wrapper_classes( $gift_wrapper_id, $current_item = false ) {
		$classes = array(
			'gtw-slide-order-gift-wrapper-item',
			'gtw-slide-order-gift-wrapper-list',
			'gtw-slide-order-gift-wrapper-item-' . $gift_wrapper_id,
				) ;

		if ( $gift_wrapper_id == $current_item ) {
			$classes[] = 'gtw_current' ;
		}

		/**
		 * This hook is used to alter the slide order gift wrapper classes.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_slide_order_gift_wrapper_classes' , $classes , $gift_wrapper_id , $current_item ) ;
	}

}

if ( ! function_exists( 'gtw_get_popup_product_gift_wrapper_classes' ) ) {

	/**
	 *  Get the product gift wrapper popup classes.
	 *
	 *  @return array
	 */
	function gtw_get_popup_product_gift_wrapper_classes( $gift_wrapper_id, $current_item = false ) {
		$classes = array(
			'gtw-popup-product-gift-wrapper-item',
			'gtw-popup-product-gift-wrapper-list',
			'gtw-popup-product-gift-wrapper-list-' . $gift_wrapper_id,
				) ;

		if ( $gift_wrapper_id == $current_item ) {
			$classes[] = 'gtw_current' ;
		}

		return $classes ;
	}

}

if ( ! function_exists( 'gtw_get_product_gift_wrapper_classes' ) ) {

	/**
	 *  Get the product gift wrapper classes.
	 *
	 *  @return array
	 */
	function gtw_get_product_gift_wrapper_classes( $gift_wrapper_id, $current_item ) {
		$classes = array(
			'gtw-product-gift-wrapper-item',
			'gtw-gift-wrapper-select',
			'gtw-product-gift-wrapper-item-' . $gift_wrapper_id,
				) ;

		if ( $gift_wrapper_id == $current_item ) {
			$classes[] = 'gtw_current' ;
		}

		return $classes ;
	}

}

if ( ! function_exists( 'gtw_get_field_wrapper_classes' ) ) {

	/**
	 *  Get the field wrapper classes.
	 *
	 *  @return array
	 */
	function gtw_get_field_wrapper_classes( $field_key ) {
		$classes = array(
			'gtw-gift-wrapper-field',
			'gtw-product-gift-wrapper-field-' . $field_key,
				) ;

		return $classes ;
	}

}

if ( ! function_exists( 'gtw_get_formatted_textarea_field_description' ) ) {

	/**
	 *  Get the textarea field description.
	 *
	 *  @return string
	 */
	function gtw_get_formatted_textarea_field_description( $field ) {
		$description   = gtw_get_custom_field_description( $field ) ;
		$message_count = empty( $field->get_character_count() ) ? 1000 : $field->get_character_count() ;

		$find_array    = array( '{remaining_characters}', '{max_characters}' ) ;
		$replace_array = array( '<span class="gtw-gift-wrapper-message-count" data-max="' . $message_count . '">' . $message_count . '</span>', $message_count ) ;

		return str_replace( $find_array , $replace_array , $description ) ;
	}

}

if ( ! function_exists( 'gtw_display_gift_wrapper_designs' ) ) {

	/**
	 * Display the gift wrapper designs.
	 *
	 *  @return bool
	 */
	function gtw_display_gift_wrapper_designs() {
		$return = true ;
		if ( '2' == get_option( 'gtw_settings_gift_wrapper_design_type' ) ) {
			$return = false ;
		}

		/**
		 * This hook is used to alter the gift wrapper designs.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_display_gift_wrapper_designs' , $return ) ;
	}

}

if ( ! function_exists( 'gtw_get_order_gift_wrapper_button_label' ) ) {

	/**
	 *  Get the order gift wrapper button label.
	 *
	 *  @return string
	 */
	function gtw_get_order_gift_wrapper_button_label( $product ) {
		$label = get_option( 'gtw_settings_order_gift_wrapper_localization' ) ;

		if ( ! gtw_display_gift_wrapper_designs() ) {
			$design_price = floatval( get_option( 'gtw_settings_gift_wrapper_design_price' ) ) ;
			$label        .= ' (' . gtw_price( gtw_get_price_to_display( $product , gtw_convert_price( $design_price ) ) ) . ')' ;
		}

		/**
		 * This hook is used to alter the order gift wrapper button label.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_order_gift_wrapper_button_label' , $label ) ;
	}

}

if ( ! function_exists( 'gtw_get_order_gift_wrapper_popup_title_label' ) ) {

	/**
	 *  Get the order gift wrapper popup title label.
	 *
	 *  @return string
	 */
	function gtw_get_order_gift_wrapper_popup_title_label( $product ) {
		$label = get_option( 'gtw_settings_gift_wrapper_design_localization' ) ;

		if ( ! gtw_display_gift_wrapper_designs() ) {
			$design_price = floatval( get_option( 'gtw_settings_gift_wrapper_design_price' ) ) ;
			$label        .= ' (' . gtw_price( gtw_get_price_to_display( $product , gtw_convert_price( $design_price ) ) ) . ')' ;
		}

		/**
		 * This hook is used to alter the order gift wrapper popup title label.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_order_gift_wrapper_popup_title_label' , $label ) ;
	}

}

if ( ! function_exists( 'gtw_get_product_gift_wrapper_label' ) ) {

	/**
	 *  Get the product gift wrapper label.
	 *
	 *  @return string
	 */
	function gtw_get_product_gift_wrapper_label( $product ) {
		$label = get_option( 'gtw_settings_product_gift_wrapper_localization' ) ;

		if ( ! gtw_display_gift_wrapper_designs() ) {
			$design_price = floatval( get_option( 'gtw_settings_gift_wrapper_design_price' ) ) ;
			$label        .= '(' . gtw_price( gtw_get_price_to_display( $product , gtw_convert_price( $design_price ) ) ) . ')' ;
		}

		/**
		 * This hook is used to alter the product gift wrapper label.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_product_gift_wrapper_label' , $label ) ;
	}

}

if ( ! function_exists( 'gtw_get_custom_field_name' ) ) {

	/**
	 *  Get the custom field name.
	 *
	 *  @return string
	 */
	function gtw_get_custom_field_name( $field ) {
		$name = gtw_get_custom_field_translate_string( 'gtw_custom_field_name_' . $field->get_id() , $field->get_name() ) ;

		/**
		 * This hook is used to alter the custom field name.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_custom_field_name' , $name , $field ) ;
	}

}

if ( ! function_exists( 'gtw_get_custom_field_description' ) ) {

	/**
	 *  Get the custom field description.
	 *
	 *  @return string
	 */
	function gtw_get_custom_field_description( $field ) {
		$description = gtw_get_custom_field_translate_string( 'gtw_custom_field_description_' . $field->get_id() , $field->get_description() ) ;

		/**
		 * This hook is used to alter the custom field description.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_custom_field_description' , $description , $field ) ;
	}

}

if ( ! function_exists( 'gtw_show_product_gift_wrapper_total_payable' ) ) {

	/**
	 * Show the product gift wrapper total payable.
	 *
	 * @return string.
	 *
	 * */
	function gtw_show_product_gift_wrapper_total_payable() {
		/**
		 * This hook is used to check if a product gift wrapper total payable is valid to display.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_show_product_gift_wrapper_total_payable' , 'yes' !== get_option( 'gtw_settings_disable_product_gift_wrapper_total_payable' , 'no' ) ) ;
	}

}

if ( ! function_exists( 'gtw_get_product_gift_wrapper_checkbox_classes' ) ) {

	/**
	 *  Get the product gift wrapper checkbox classes.
	 *
	 *  @return array
	 */
	function gtw_get_product_gift_wrapper_checkbox_classes() {
		$classes = array(
			'gtw-product-gift-wrapper-enable',
				) ;

		if ( '2' === get_option( 'gtw_settings_force_product_gift_wrapper' ) ) {
			$classes[] = 'gtw-readonly' ;
		}

		/**
		 * This hook is used to alter the product gift wrapper checkbox classes.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_product_gift_wrapper_checkbox_classes' , $classes ) ;
	}

}

if ( ! function_exists( 'gtw_get_product_gift_wrapper_checked_attribute' ) ) {

	/**
	 *  Get the product gift wrapper checked attribute.
	 *
	 *  @return string
	 */
	function gtw_get_product_gift_wrapper_checked_attribute() {
		if ( '2' !== get_option( 'gtw_settings_force_product_gift_wrapper' ) ) {
			return '' ;
		}

		return "checked='checked'" ;
	}

}

if ( ! function_exists( 'gtw_get_order_gift_wrapper_checked_attribute' ) ) {

	/**
	 *  Get the order gift wrapper checked attribute.
	 *
	 *  @since 5.1.0
	 *  @return string
	 */
	function gtw_get_order_gift_wrapper_checked_attribute() {
		if ( ! gtw_order_gift_wrapper_in_cart() ) {
			return '' ;
		}

		return "checked='checked'" ;
	}

}

if ( ! function_exists( 'gtw_get_product_gift_wrapper_items_classes' ) ) {

	/**
	 *  Get the product gift wrapper items classes.
	 *
	 *  @return array
	 */
	function gtw_get_product_gift_wrapper_items_classes() {
		$classes = array(
			'gtw-product-gift-wrapper-items-content',
				) ;

		if ( '2' !== get_option( 'gtw_settings_force_product_gift_wrapper' ) ) {
			$classes[] = 'gtw-gift-wrapper' ;
		}

		/**
		 * This hook is used to alter the product gift wrapper items classes.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_product_gift_wrapper_items_classes' , $classes ) ;
	}

}

if ( ! function_exists( 'gtw_get_product_total_payable_wrapper_classes' ) ) {

	/**
	 *  Get the product total payable wrapper classes.
	 *
	 *  @return array
	 */
	function gtw_get_product_total_payable_wrapper_classes() {
		$classes = array(
			'gtw-product-gift-wrapper-total-payable-content',
				) ;

		if ( '2' !== get_option( 'gtw_settings_force_product_gift_wrapper' ) ) {
			$classes[] = 'gtw-gift-wrapper' ;
		}

		/**
		 * This hook is used to alter the product total payable wrapper classes.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_product_total_payable_wrapper_classes' , $classes ) ;
	}

}

if ( ! function_exists( 'gtw_get_product_gift_wrapper_fields_classes' ) ) {

	/**
	 *  Get the product gift wrapper fields classes.
	 *
	 *  @return array
	 */
	function gtw_get_product_gift_wrapper_fields_classes() {
		$classes = array(
			'gtw-product-gift-wrapper-fields',
				) ;

		if ( '2' !== get_option( 'gtw_settings_force_product_gift_wrapper' ) ) {
			$classes[] = 'gtw-gift-wrapper' ;
		}

		/**
		 * This hook is used to alter the product gift wrapper fields classes.
		 * 
		 * @since 1.0
		 */
		return apply_filters( 'gtw_product_gift_wrapper_fields_classes' , $classes ) ;
	}

}
