<?php
/**
 * This template displays the product gift wrapper.
 *
 * This template can be overridden by copying it to yourtheme/gift-wrapper-for-woocommerce/product-gift-wrapper.php
 *
 * To maintain compatibility, Gift Wrapper for WooCommerce will update the template files and you have to copy the updated files to your theme
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit ; // Exit if accessed directly.
}
?>
<div class="gtw-product-gift-wrapper">
	<div class="gtw-product-gift-wrapper-content">

		<div class="gtw-product-gift-wrapper-enable-field">
			<label><?php echo wp_kses_post( gtw_get_product_gift_wrapper_label( $product ) ) ; ?></label>
			<input type="checkbox" name="gtw_enable_gift_wrapper" class="<?php echo esc_attr( implode( ' ', gtw_get_product_gift_wrapper_checkbox_classes() ) ) ; ?>"
				   <?php echo esc_attr( gtw_get_product_gift_wrapper_checked_attribute() ) ; ?>/>
		</div>

		<?php
		/**
		 * The hook is used to display content before product gift wrapper summary.
		 *
		 * @since 1.0
		 * */
		do_action( 'gtw_before_product_gift_wrapper_summary' ) ;
		?>

		<?php if ( gtw_display_gift_wrapper_designs() ) : ?>
			<div class="<?php echo esc_attr( implode( ' ', gtw_get_product_gift_wrapper_items_classes() ) ) ; ?>">
				<h4><?php echo wp_kses_post( get_option( 'gtw_settings_gift_wrapper_design_localization' ) ) ; ?></h4>
				<p class="gtw-product-gift-wrapper-description">
					<span class="gtw-product-gift-wrapper-name"><?php echo esc_html( $gift_wrapper_name ) ; ?></span>
					<span class="gtw-product-gift-wrapper-price"><strong><?php echo '(' . wp_kses_post( $gift_wrapper_price ) . ')' ; ?></strong></span>
				</p>

				<?php
				/**
				 * The hook is used to display content of product gift wrapper items.
				 *
				 * @hooked GTW_Frontend::render_product_gift_wrapper_items - 10
				 * @hooked GTW_Frontend::render_slide_product_gift_wrapper_items - 10
				 * @since 1.0
				 * */
				do_action( 'gtw_product_gift_wrapper_items', $product ) ;
				?>

				<input type="hidden" class="gtw-product-gift-wrapper-product-id" value="<?php echo esc_attr( $product->get_id() ) ; ?>"/>
			</div>
		<?php endif ; ?>

		<?php
		/**
		 * The hook is used to display content after product gift wrapper summary.
		 *
		 * @hooked GTW_Frontend::render_product_gift_wrapper_custom_fields - 20
		 * @since 1.0
		 * */
		do_action( 'gtw_after_product_gift_wrapper_summary' ) ;
		?>

		<?php if ( gtw_show_product_gift_wrapper_total_payable() ) : ?>
			<div class="<?php echo esc_attr( implode( ' ', gtw_get_product_total_payable_wrapper_classes() ) ) ; ?>">
				<label><?php echo wp_kses_post( get_option( 'gtw_settings_gift_wrapper_total_payable_localization' ) ) ; ?></label>
				<span class="gtw-product-gift-wrapper-total-payable"><strong><?php echo wp_kses_post( $total_payable ) ; ?></strong></span>
			</div>
		<?php endif ; ?>
	</div>
</div>
<?php
